Datum

Enum Datum 

pub enum Datum {
    Boolean(bool),
    Number(Decimal),
    Date(NaiveDate),
    Time(NaiveTime),
    DateTime(NaiveDateTime),
    String(String),
}
Value for a field in an ADIF record.

ADIF fields can have various types specified in their tags. If no type is specified, they default to strings. This enum represents all possible typed values, and provides methods to coerce between types.

Variants



Boolean(bool)

Boolean value (type indicator b in ADIF tags).



Number(Decimal)

Numeric value (type indicator n in ADIF tags).



Date(NaiveDate)

Date value (type indicator d in ADIF tags), format YYYYMMDD.



Time(NaiveTime)

Time value (type indicator t in ADIF tags), format HHMMSS.



DateTime(NaiveDateTime)

Combined date and time value.

This type is not part of the ADIF specification, but it provided as a convenience, e.g. for output by a data normalizer that could combine date and time into a single field.

This type can be output via the output module provided that the writer is configured to not output a type indicator for the datetime field. Attempting to output a datetime with a type indicator will return an error.



String(String)

String value (default when no type indicator is present).

Implementations

Source

impl Datum

pub fn as_bool(&self) -> Option<bool>

Return a bool value or coerce a string thereto.

Returns None if a string value fails to parse.

pub fn as_number(&self) -> Option<Decimal>

Return a numeric value as a Decimal or coerce a string thereto.

Returns None if a string value fails to parse.

pub fn as_date(&self) -> Option<NaiveDate>

Return a date value as a NaiveDate or coerce a string thereto.

Returns None if a string value fails to parse.

pub fn as_time(&self) -> Option<NaiveTime>

Return a time value as a NaiveTime or coerce a string thereto.

Returns None if a string value fails to parse.

pub fn as_datetime(&self) -> Option<NaiveDateTime>

Return a datetime value as a NaiveDateTime or coerce a string thereto.

Returns None if a string value fails to parse.

pub fn as_str(&self) -> Cow<'_, str>

Coerce any datum to a string representation.

String variants return borrowed data. All other types are returned in ADIF format (boolean Y/N, date YYYYMMDD, time HHMMSS).

pub fn to_cabrillo(&self) -> Cow<'_, str>

Coerce any datum to Cabrillo format string representation.