CiString

Struct CiString 

pub struct CiString(/* private fields */);
A case-insensitive string that preserves the original case.

This type stores a string in its original case but implements case-insensitive equality and hashing, making it suitable for use as a key in hash maps that should be case-preserving but wherein case-insensitive lookups are desired.

Implementations

Source

impl CiString

pub fn as_str(&self) -> &str

Returns a string slice of the original case string.

pub fn into_string(self) -> String

Converts this CiString into the underlying String.