pub struct CiString(/* private fields */);Expand description
A case-insensitive string that preserves the original case.
This type stores a string in its original case but implements case-insensitive equality and hashing, making it suitable for use as a key in hash maps that should be case-preserving but wherein case-insensitive lookups are desired.
Implementations